@@ -57,10 +57,10 @@ set_class <- function(x, class) {
 }
 
 #' @export
-.estimates <- function(object, fun = median) {
+.estimates <- function(object, fun = median, ...) {
   stopifnot(is.matrix(object))
   nrow <- nrow(object)
-  object <- apply(object, 1L, fun)
+  object <- apply(object, 1L, fun, ...)
   if (!identical(dims(object), nrow)) abort_chk("`fun` must return a scalar")
   if (!is.numeric(object)) abort_chk("`fun` must return a numeric")
   object
