@@ -7,14 +7,6 @@ niters.matrix <- function(x, ...) ncol(x)
 #' @export
 niters.mcarray <- function(x, ...) unname(dim(x)[ndims(x) - 1])
 
-#' @inherit universals::niters
-#' @export
-niters.mcmc <- function(x, ...) nrow(x)
-
-#' @inherit universals::niters
-#' @export
-niters.mcmc.list <- function(x, ...) niters(x[[1]])
-
 #' @inherit universals::niters
 #' @export
 niters.mcmcarray <- function(x, ...) dim(x)[2]
