@@ -6,16 +6,16 @@ test_that("combine_dimensions.mcmcarray", {
   expect_identical(pdims(combine_dimensions(mcmcr_example$alpha)), 1L)
   expect_identical(pdims(combine_dimensions(mcmcr_example$sigma)), 1L)
   expect_identical(pdims(combine_dimensions(mcmcr_example2$sigma, along = 1L)), c(1L, 1L))
-  expect_equal(combine_dimensions(bind_dimensions(mcmcr_example2$beta, mcmcr_example2$beta)), mcmcr_example2$beta, check.attributes = FALSE)
+  expect_equal(combine_dimensions(bind_dimensions(mcmcr_example2$beta, mcmcr_example2$beta)), mcmcr_example2$beta, ignore_attr = FALSE)
 })
 
 test_that("combine_dimensions.mcmcr", {
   expect_equal(combine_dimensions(bind_dimensions_n(mcmcr_example, mcmcr_example, mcmcr_example)),
     mcmcr_example,
-    check.attributes = FALSE
+    ignore_attr = FALSE
   )
   expect_equal(combine_dimensions(bind_dimensions_n(mcmcr_example2, mcmcr_example2, mcmcr_example2)),
     mcmcr_example2,
-    check.attributes = FALSE
+    ignore_attr = FALSE
   )
 })
