@@ -1,6 +1,6 @@
 test_that("ess.mcmcmarray", {
   expect_identical(ess(mcmcr_example[[1]], by = "term"), c(9L, 9L))
-  expect_equivalent(ess(mcmcr_example[[2]], by = "term"), matrix(c(40L, 40L, 40L, 40L), nrow = 2))
+  expect_equal(ess(mcmcr_example[[2]], by = "term"), matrix(c(40L, 40L, 40L, 40L), nrow = 2))
   expect_identical(ess(mcmcr_example[[3]], by = "term"), c(378L))
   expect_identical(ess(mcmcr_example[[2]]), 40L)
   expect_identical(ess(mcmcr_example[[1]], "parameter"), ess(mcmcr_example[[1]], "all"))
@@ -20,11 +20,8 @@ test_that("ess.mcmcr as df", {
       "tbl", "data.frame"
     ))
   )
-  skip_if(packageVersion("testthat") < '2.99.0.9000')
-
-  expect_identical(ess(mcmcr_example, as_df = TRUE, by = "parameter"),
-                   tibble::tibble(parameter = c("alpha", "beta", "sigma"),
-                                   ess = c(9L, 40L, 378L)))
+  expect_snapshot_data(ess(mcmcr_example, as_df = TRUE, by = "parameter"),
+                       "ess")
 })
 
 test_that("ess.mcmcrs", {
